## Tests

- list_calendar_events: ✅

- list_drive_files: ✅

- read_latest_gmail_email: ✅

- create_calendar_event: ✅

- read_email_by_subject: ✅

- send_email: ✅

- delete_calendar_event: ✅

- update_calendar_event: ✅

- create_drive_document: (creates only google docs) ✅

- update_drive_document: (overwriting only, no append mode nor edit mode like in Google Docs App) ✅

- delete_drive_file: ✅

- move_drive_file_to_bin: ✅ 